@@ -5,7 +5,7 @@ from abstract_apis import get_headers,get_response
 import requests,asyncio
 async def call_async_function(func, *args, **kwargs):
     """Helper function to call async functions in sync or async contexts."""
-    if asyncio.isrunning():
+    if asyncio.get_event_loop().is_running():
         # If an event loop is already running, use await
         return await func(*args, **kwargs)
     else:
